==> bitsensor-node-js-test-server-1.0.1.tgz: package/test/bitsensor_end_test.js <==
var bitSensorServer = require('../core/bitsensor_server');
var cls = require('continuation-local-storage');

var expect = require('chai').expect;
var chai = require('chai');
var chaiHttp = require('chai-http');
chai.use(chaiHttp);
process.env.NODE_TLS_REJECT_UNAUTHORIZED = "0";

describe('End to end test', function () {
  after('Close servers', (done) => {
    bitSensorServer.server.close();
    done()
  });
  beforeEach(() => {
    dataCollector.length = 0;
  });
  let clientServer;
  describe('app.listen monkey patch', function () {

    before(() => clientServer = require('../core/client_server'));

    after(() => {
      clientServer.server.close();
      cls.destroyNamespace('bitsensor');
      cls.createNamespace('bitsensor');
    });

    describe('succesful test', function () {
      it('handling request should be done', function (done) {
        chai.request('http://localhost:3003')
          .get('/')
          .end(function () {
            expect(bitSensor.isHandlingRequest).to.be.null;
            done();
          });
      });
      it('response should be approved', function (done) {
        chai.request('http://localhost:3003')
          .get('/')
          .end(function (err, res) {
            expect(res.res.socket._httpMessage.res.text).to.equal('approved');
            done();
          });
      });
      it('should send at least one datapoint', function (done) {
        bitSensor.runSession(function () {
          chai.request('http://localhost:3003')
            .get('/')
            .end(function (err, res) {
            });
          setTimeout(() => {
            data = JSON.parse(dataCollector[dataCollector.length - 1].data);
            expect(data).to.be.an('object');
            expect(data.context).to.have.property('ip');
            expect(data.endpoint).to.have.property('port', '3003');
            expect(data.meta).to.have.property('provider', 'bitsensor-nodejs');
            done();
          }, 100);
        });
      });
    });
    describe('error test', function () {
      it('response should be error', function (done) {
        bitSensor.runSession(function () {
          chai.request('http://localhost:3003')
            .get('/err')
            .end(function (err, res) {
              expect(res.res.socket._httpMessage.res.text).to.not.equal(200);
              done();
            });
        });
      });
      it('should contain error', function (done) {
        bitSensor.runSession(function () {
          chai.request('http://localhost:3003')
            .get('/err')
            .end(function () {
            });
        });
        setTimeout(() => {
          data = JSON.parse(dataCollector[dataCollector.length - 1].data);
          expect(data).to.be.an('object');
          expect(data.errors).has.lengthOf(1);
          done();
        }, 100);
      });
    });
    describe('httphandlerManager middleware', function () {
      it('should not be null', function (done) {
        expect(httpHandlerManager).to.not.be.undefined;
        done();
      });
    });
  });

  describe('http server monkey patch end to end test', function () {

    before(() => clientServer = require('../core/http_server'));

    after(() => {
      clientServer.server.close();
      cls.destroyNamespace('bitsensor');
      cls.createNamespace('bitsensor');
    });

    describe('succesful test', function () {
      it('handling request should be done', function (done) {
        chai.request('http://localhost:3004')
          .get('/')
          .end(function (err, res) {
            expect(bitSensor.isHandlingRequest).to.be.null;
            done();
          });
      });
      it('response should be approved', function (done) {
        chai.request('http://localhost:3004')
          .get('/')
          .end(function (err, res) {
            expect(res.res.socket._httpMessage.res.text).to.equal('approved');
            done();
          });
      });
      it('should send at least one datapoint', function (done) {
        bitSensor.runSession(function () {
          chai.request('http://localhost:3004')
            .get('/')
            .end(function () {
            });
        });
        setTimeout(() => {
          data = JSON.parse(dataCollector[dataCollector.length - 1].data);
          expect(data).to.be.an('object');
          expect(data.context).to.have.property('ip');
          expect(data.endpoint).to.have.property('port', '3004');
          expect(data.meta).to.have.property('provider', 'bitsensor-nodejs');
          done();
        }, 100);
      });
    });
    describe('error test', function () {
      it('response should be error', function (done) {
        bitSensor.runSession(function () {
          chai.request('http://localhost:3004')
            .get('/err')
            .end(function (err, res) {
              expect(res.res.socket._httpMessage.res.text).to.not.equal(200);
              done();
            });
        });
      });
      it('should contain error', function (done) {
        bitSensor.runSession(function () {
          chai.request('http://localhost:3004')
            .get('/err')
            .end(function () {
            });
        });
        setTimeout(() => {
          data = JSON.parse(dataCollector[dataCollector.length - 1].data);
          expect(data).to.be.an('object');
          expect(data.errors).to.have.lengthOf(1);
          done();
        }, 100);
      });
    });
  });
  // HTTPS
  describe('https server monkey patch end to end test', function () {

    before(() => clientServer = require('../core/https_server'));

    after(() => {
      clientServer.server.close();
      cls.destroyNamespace('bitsensor');
      cls.createNamespace('bitsensor');
    });

    describe('succesful test', function () {
      it('handling request should be done', function (done) {
        chai.request('https://localhost:8443')
          .get('/')
          .end(function (err, res) {
            expect(bitSensor.isHandlingRequest).to.be.null;
            done();
          });
      });
      it('response should be approved', function (done) {
        chai.request('https://localhost:8443')
          .get('/')
          .end(function (err, res) {
            expect(res.res.socket._httpMessage.res.text).to.equal('approved');
            done();
          });
      });
      it('should send at least one datapoint', function (done) {
        bitSensor.runSession(function () {
          chai.request('https://127.0.0.1:8443')
            .get('/')
            .end(function () {
            });
        });
        setTimeout(() => {
          data = JSON.parse(dataCollector[dataCollector.length - 1].data);
          expect(data).to.be.an('object');
          expect(data.context).to.have.property('ip');
          expect(data.endpoint).to.have.property('port', '8443');
          expect(data.meta).to.have.property('provider', 'bitsensor-nodejs');
          done();
        }, 100);
      });
    });
    describe('error test', function () {
      it('response should be error', function (done) {
        bitSensor.runSession(function () {
          chai.request('https://localhost:8443')
            .get('/err')
            .end(function (err, res) {
              expect(res.res.socket._httpMessage.res.text).to.not.equal(200);
              done();
            });
        });
      });
      it('should contain error', function (done) {
        bitSensor.runSession(function () {
          chai.request('https://localhost:8443')
            .get('/err')
            .end(function () {
            });
        });
        setTimeout(() => {
          data = JSON.parse(dataCollector[dataCollector.length - 1].data);
          expect(data).to.be.an('object');
          expect(data.errors).to.have.lengthOf(1);
          done();
        }, 100);
      });
    });
  });
});

==> bitsensor-node-js-test-server-1.1.0.tgz: package/test/bitsensor_end_test.js <==
var bitSensorServer = require('../core/bitsensor_server');
var cls = require('continuation-local-storage');

var expect = require('chai').expect;
var chai = require('chai');
var chaiHttp = require('chai-http');
chai.use(chaiHttp);
process.env.NODE_TLS_REJECT_UNAUTHORIZED = "0";

describe('End to end test', function () {
  after('Close servers', (done) => {
    bitSensorServer.server.close();
    done()
  });
  beforeEach(() => {
    dataCollector.length = 0;
  });
  let clientServer;
  describe('app.listen monkey patch', function () {

    before(() => clientServer = require('../core/client_server'));

    after(() => {
      clientServer.server.close();
      cls.destroyNamespace('bitsensor');
      cls.createNamespace('bitsensor');
    });

    describe('succesful test', function () {
      it('handling request should be done', function (done) {
        chai.request('http://localhost:3003')
          .get('/')
          .end(function () {
            expect(bitSensor.getHandlingRequest()).to.be.undefined;
            done();
          });
      });
      it('response should be approved', function (done) {
        chai.request('http://localhost:3003')
          .get('/')
          .end(function (err, res) {
            expect(res.res.socket._httpMessage.res.text).to.equal('approved');
            done();
          });
      });
      it('should send at least one datapoint', function (done) {
        bitSensor.runSession(function () {
          chai.request('http://localhost:3003')
            .get('/')
            .end(function (err, res) {
            });
          setTimeout(() => {
            data = JSON.parse(dataCollector[dataCollector.length - 1].data);
            expect(data).to.be.an('object');
            expect(data.context).to.have.property('ip');
            expect(data.endpoint).to.have.property('port', '3003');
            expect(data.meta).to.have.property('provider', 'bitsensor-nodejs');
            done();
          }, 100);
        });
      });
    });
    describe('error test', function () {
      it('response should be error', function (done) {
        bitSensor.runSession(function () {
          chai.request('http://localhost:3003')
            .get('/err')
            .end(function (err, res) {
              expect(res.res.socket._httpMessage.res.text).to.not.equal(200);
              done();
            });
        });
      });
      it('should contain error', function (done) {
        bitSensor.runSession(function () {
          chai.request('http://localhost:3003')
            .get('/err')
            .end(function () {
            });
        });
        setTimeout(() => {
          data = JSON.parse(dataCollector[dataCollector.length - 1].data);
          expect(data).to.be.an('object');
          expect(data.errors).has.lengthOf(1);
          done();
        }, 100);
      });
    });
    describe('httphandlerManager middleware', function () {
      it('should not be undefined', function (done) {
        expect(httpHandlerManager).to.not.be.undefined;
        done();
      });
    });
  });

  describe('http server monkey patch end to end test', function () {

    before(() => clientServer = require('../core/http_server'));

    after(() => {
      clientServer.server.close();
      cls.destroyNamespace('bitsensor');
      cls.createNamespace('bitsensor');
    });

    describe('succesful test', function () {
      it('handling request should be done', function (done) {
        chai.request('http://localhost:3004')
          .get('/')
          .end(function (err, res) {
            expect(bitSensor.getHandlingRequest()).to.be.undefined;
            done();
          });
      });
      it('response should be approved', function (done) {
        chai.request('http://localhost:3004')
          .get('/')
          .end(function (err, res) {
            expect(res.res.socket._httpMessage.res.text).to.equal('approved');
            done();
          });
      });
      it('should send at least one datapoint', function (done) {
        bitSensor.runSession(function () {
          chai.request('http://localhost:3004')
            .get('/')
            .end(function () {
            });
        });
        setTimeout(() => {
          data = JSON.parse(dataCollector[dataCollector.length - 1].data);
          expect(data).to.be.an('object');
          expect(data.context).to.have.property('ip');
          expect(data.endpoint).to.have.property('port', '3004');
          expect(data.meta).to.have.property('provider', 'bitsensor-nodejs');
          done();
        }, 100);
      });
    });
    describe('error test', function () {
      it('response should be error', function (done) {
        bitSensor.runSession(function () {
          chai.request('http://localhost:3004')
            .get('/err')
            .end(function (err, res) {
              expect(res.res.socket._httpMessage.res.text).to.not.equal(200);
              done();
            });
        });
      });
      it('should contain error', function (done) {
        bitSensor.runSession(function () {
          chai.request('http://localhost:3004')
            .get('/err')
            .end(function () {
            });
        });
        setTimeout(() => {
          data = JSON.parse(dataCollector[dataCollector.length - 1].data);
          expect(data).to.be.an('object');
          expect(data.errors).to.have.lengthOf(1);
          done();
        }, 100);
      });
    });
  });
  // HTTPS
  describe('https server monkey patch end to end test', function () {

    before(() => clientServer = require('../core/https_server'));

    after(() => {
      clientServer.server.close();
      cls.destroyNamespace('bitsensor');
      cls.createNamespace('bitsensor');
    });

    describe('succesful test', function () {
      it('handling request should be done', function (done) {
        chai.request('https://localhost:8443')
          .get('/')
          .end(function (err, res) {
            expect(bitSensor.getHandlingRequest()).to.be.undefined;
            done();
          });
      });
      it('response should be approved', function (done) {
        chai.request('https://localhost:8443')
          .get('/')
          .end(function (err, res) {
            expect(res.res.socket._httpMessage.res.text).to.equal('approved');
            done();
          });
      });
      it('should send at least one datapoint', function (done) {
        bitSensor.runSession(function () {
          chai.request('https://127.0.0.1:8443')
            .get('/')
            .end(function () {
            });
        });
        setTimeout(() => {
          data = JSON.parse(dataCollector[dataCollector.length - 1].data);
          expect(data).to.be.an('object');
          expect(data.context).to.have.property('ip');
          expect(data.endpoint).to.have.property('port', '8443');
          expect(data.meta).to.have.property('provider', 'bitsensor-nodejs');
          done();
        }, 100);
      });
    });
    describe('error test', function () {
      it('response should be error', function (done) {
        bitSensor.runSession(function () {
          chai.request('https://localhost:8443')
            .get('/err')
            .end(function (err, res) {
              expect(res.res.socket._httpMessage.res.text).to.not.equal(200);
              done();
            });
        });
      });
      it('should contain error', function (done) {
        bitSensor.runSession(function () {
          chai.request('https://localhost:8443')
            .get('/err')
            .end(function () {
            });
        });
        setTimeout(() => {
          data = JSON.parse(dataCollector[dataCollector.length - 1].data);
          expect(data).to.be.an('object');
          expect(data.errors).to.have.lengthOf(1);
          done();
        }, 100);
      });
    });
  });
});
